package websocket

import (
	"encoding/json"
	"github.com/charmbracelet/log"
	"github.com/gorilla/websocket"

	ChronoTomato "git.smsvc.net/pomodoro/ChronoTomato/pkg/models"
	GoTomato "git.smsvc.net/pomodoro/GoTomato/pkg/models"
)

type Client ChronoTomato.PomodoroClient // New websocket client

func (c Client) sendClientCommand(msg GoTomato.ClientCommand) {
	messageBytes, err := json.Marshal(msg)
	if err != nil {
		log.Error("Error marshalling!", "reason", err)
		return
	}

	err = c.Conn.WriteMessage(websocket.TextMessage, messageBytes)
	if err != nil {
		log.Error("Write error!", "reason", err)
		return
	}
}

func (c Client) SendCmd(pwd string, cmd string) {
	message := GoTomato.ClientCommand{
		Command:  cmd,
		Password: pwd,
	}

	c.sendClientCommand(message)
}

func (c Client) SendSettingsUpdate(pwd string, settings GoTomato.PomodoroConfig) {
	message := GoTomato.ClientCommand{
		Command:  "updateSettings",
		Password: pwd,
		Settings: settings,
	}

	c.sendClientCommand(message)
}
